@@ -1,4 +1,4 @@
-# $Id: Define.pm 49231 2008-01-03 16:53:43Z wsnyder $
+# $Id: Define.pm 60834 2008-09-15 15:43:15Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use Verilog::Language;	# For value parsing
 use strict;
 use vars qw ($VERSION);
 use base qw (SystemC::Vregs::Subclass);
-$VERSION = '1.450';
+$VERSION = '1.460';
 
 #Fields:
 #	{name}			Field name (Subclass)
@@ -31,7 +31,7 @@ $VERSION = '1.450';
 #	{bits}			Width or undef for unsized
 #	{desc}			Description
 #	{rst}			Reset value or 'X'
-#	{rst_val}		{rst} as a hex value	
+#	{rst_val}		{rst} as a hex value
 #	{sort_key}		Order to output into file
 #	{is_manual}		Created by user (vs from program)
 
@@ -164,7 +164,7 @@ sub dump {
     my $indent = shift||"  ";
     print $fh +($indent,"Def: ",$self->{name},
 		"  width:",$self->{bits}||'',
-		"  rst:",$self->{rst}||'', 
+		"  rst:",$self->{rst}||'',
 		"  rst_val:",$self->{rst_val}||'',
 		"\n");
 }
@@ -253,9 +253,9 @@ Checks the object for errors, and parses to create derived Fields.
 
 =head1 DISTRIBUTION
 
-Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
+Vregs is part of the L<http://www.veripool.org/> free Verilog software tool
 suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
+L<http://www.veripool.org/vregs>.  /www.veripool.org/>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
