@@ -1,4 +1,4 @@
-# $Id: Register.pm 49231 2008-01-03 16:53:43Z wsnyder $
+# $Id: Register.pm 60834 2008-09-15 15:43:15Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use Bit::Vector::Overload;
 use strict;
 use vars qw ($VERSION);
 use base qw (SystemC::Vregs::Subclass);
-$VERSION = '1.450';
+$VERSION = '1.460';
 
 # Fields:
 #	{name}			Field name (Subclass)
@@ -29,10 +29,10 @@ $VERSION = '1.450';
 #	{at}			File/line number (Subclass)
 #	{pack}			Parent SystemC::Vregs ref
 #	{typeref}		Owning SystemC::Vregs::Type ref
-#	{addrtext}	
+#	{addrtext}
 #	{addr}			Beginning SystemC::Vregs::Addr
 #	{addr_end}		Ending SystemC::Vregs::Addr (exclusive < end).
-#	{spacingtext}	
+#	{spacingtext}
 #	{range}			Range text
 #	{range_high}		SystemC::Vregs::Addr
 #	{range_low}		SystemC::Vregs::Addr
@@ -81,7 +81,7 @@ sub dewildcard {
     #	  rst  => $self->{addrtext},
     #	  desc => "Base address from wildcarded register range",
     #	  );
-    
+
     my $gotone;
     foreach my $matchref ($self->{pack}->find_reg_regexp("^$regexp")) {
 	$gotone = 1;
@@ -182,7 +182,7 @@ sub check_range_spacing {
     else { # No range
 	($spacing->equal($regref->{pack}->addr_const_vec(0)))
 	    or $regref->warn ("Address spacing set to $spacing, but no range specified\n");
-	$regref->{range_low}  
+	$regref->{range_low}
 	= $regref->{range_high}
 	= $regref->{pack}->addr_const_vec(0);
     }
@@ -349,9 +349,9 @@ Checks the object for errors, and parses to create derived fields.
 
 =head1 DISTRIBUTION
 
-Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
+Vregs is part of the L<http://www.veripool.org/> free Verilog software tool
 suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
+L<http://www.veripool.org/vregs>.  /www.veripool.org/>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
